@@ -15,7 +15,7 @@
 #include <sys/stat.h>
 #include <dirent.h>
 #include <string.h>
-#include <popt.h>
+#include <popt-gnome.h>
 #include <glib.h>
 /* I know, that is is not nice, but that is exactly, what xml-config gives us */
 #include <parser.h>
