@@ -270,11 +270,6 @@ gnome_font_unsized_closest (const char *family_name,
 
 	g_return_val_if_fail (family_name != NULL, NULL);
 
-#if 0
-	if (!fontmap) gff_refresh_fontmap ();
-	g_return_val_if_fail (fontmap != NULL, NULL);
-#endif
-
 	/* This should be reimplemented to use the gnome_font_family_hash. */
 
 	map = gp_fontmap_get ();
@@ -286,7 +281,7 @@ gnome_font_unsized_closest (const char *family_name,
 	for (l = map->fonts; l != NULL; l = l->next) {
 		entry = (GPFontEntry *) l->data;
 		if ((entry->type == GP_FONT_ENTRY_TYPE1) || (entry->type == GP_FONT_ENTRY_TYPE1_ALIAS)) {
-			if (!strcmp (family_name, entry->familyname)) {
+			if (!strcasecmp (family_name, entry->familyname)) {
 				GPFontEntryT1 * t1;
 				t1 = (GPFontEntryT1 *) entry;
 				dist = abs (weight - t1->Weight) +
@@ -764,35 +759,11 @@ gff_face_from_entry (GPFontEntry * e)
 
 	t1 = (GPFontEntryT1 *) e;
 
-#if 0
-	if (!fontmap) fontmap = g_hash_table_new (g_str_hash, g_str_equal);
-
-	face = g_hash_table_lookup (fontmap, e->name);
-	if (face) return;
-#endif
-
 	face = gtk_type_new (GNOME_TYPE_FONT_FACE);
 
-#if 0
-	face->private->fullname = g_strdup (e->name);
-	face->private->afm_fn = g_strdup (t1->afm.name);
-	face->private->pfb_fn = g_strdup (t1->pfb.name);
-	face->private->familyname = g_strdup (e->familyname);
-	face->private->speciesname = g_strdup (e->speciesname);
-	face->private->psname = g_strdup (e->psname);
-
-	face->private->alias = NULL;
-
-	if (e->type == GP_FONT_ENTRY_TYPE1_ALIAS) {
-		GPFontEntryT1Alias * t1a;
-		t1a = (GPFontEntryT1Alias *) e;
-		if (t1a->alias) face->private->alias = g_strdup (t1a->alias);
-	}
-#else
 	gp_font_entry_ref (e);
 	face->private->entry = e;
 	e->face = face;
-#endif
 
 	face->private->weight_code = t1->Weight;
 	face->private->italic = (t1->ItalicAngle < 0);
@@ -802,41 +773,8 @@ gff_face_from_entry (GPFontEntry * e)
 	face->private->ligs = NULL; /* one liglist for each glyph */
 
 	face->private->loadedfont = NULL;
-#if 0
-	g_hash_table_insert (fontmap, face->private->fullname, face);
-#endif
 }
 
-#if 0
-/* fixme: REMOVE THIS */
-static void
-gff_refresh_fontmap (void)
-{
-	GPFontMap * map;
-	GSList * l;
-
-	map = gp_fontmap_get ();
-	g_assert (map != NULL);
-
-	for (l = map->fonts; l != NULL; l = l->next) {
-		GPFontEntry * e;
-		e = (GPFontEntry *) l->data;
-		switch (e->type) {
-		case GP_FONT_ENTRY_TYPE1_ALIAS:
-		case GP_FONT_ENTRY_TYPE1:
-			gff_add_mapping ((GPFontEntryT1 *) e);
-			break;
-		case GP_FONT_ENTRY_ALIAS:
-			break;
-		default:
-			break;
-		}
-	}
-
-	gp_fontmap_release (map);
-}
-#endif
-
 static gboolean
 gnome_font_face_gt1_load (GnomeFontFace * face)
 {
@@ -919,9 +857,6 @@ gff_load_afm (GnomeFontFace * face)
 
 			priv->glyphs = g_new0 (GFFGlyphInfo, fi->numOfChars + 1);
 			priv->unimap = gp_uc_map_new ();
-#if 0
-			priv->glyphmap = g_hash_table_new (NULL, NULL);
-#endif
 
 			gff_fill_zero_glyph (face);
 
@@ -971,16 +906,10 @@ gff_load_afm (GnomeFontFace * face)
 						l = gp_multi_from_ps (info->name);
 						while (l) {
 							gp_uc_map_insert (priv->unimap, GPOINTER_TO_INT (l->data), nglyphs);
-#if 0
-							gff_assign_glyph (face, GPOINTER_TO_INT (l->data), nglyphs);
-#endif
 							l = l->next;
 						}
 					} else {
 						gp_uc_map_insert (priv->unimap, unicode, nglyphs);
-#if 0
-						gff_assign_glyph (face, unicode, nglyphs);
-#endif
 					}
 
 					nglyphs++;
@@ -1008,14 +937,8 @@ gff_load_afm (GnomeFontFace * face)
 		      /* We assume here that dingbats do not have ligatures */
 		      u = gp_unicode_from_ps (ligs->succ);
 		      succ = gnome_font_face_lookup_default (face, u);
-#if 0
-		      succ = GPOINTER_TO_INT (g_hash_table_lookup (face->private->glyphmap, GINT_TO_POINTER (u)));
-#endif
 		      u = gp_unicode_from_ps (ligs->succ);
 		      lig = gnome_font_face_lookup_default (face, u);
-#if 0
-		      lig = GPOINTER_TO_INT (g_hash_table_lookup (face->private->glyphmap, GINT_TO_POINTER (u)));
-#endif
 		      if ((succ > 0) && (lig > 0))
 			{
 			  ll = g_new (GnomeFontLigList, 1);
@@ -1049,14 +972,8 @@ gff_load_afm (GnomeFontFace * face)
 	      /* We assume here that dingbats do not have kerning */
 	      u = gp_unicode_from_ps (fi->pkd[i].name1);
 	      glyph1 = gnome_font_face_lookup_default (face, u);
-#if 0
-	      glyph1 = GPOINTER_TO_INT (g_hash_table_lookup (face->private->glyphmap, GINT_TO_POINTER (u)));
-#endif
 	      u = gp_unicode_from_ps (fi->pkd[i].name2);
 	      glyph2 = gnome_font_face_lookup_default (face, u);
-#if 0
-	      glyph2 = GPOINTER_TO_INT (g_hash_table_lookup (face->private->glyphmap, GINT_TO_POINTER (u)));
-#endif
 
 	      for (j = KERN_PAIR_HASH (glyph1, glyph2) & (ktabsize - 1);
 		   ktab[j].glyph1 != -1;
