@@ -23,13 +23,8 @@
 
 #include <config.h>
 
-#if ENABLE_SLOW_COMPILATION
-#warning Slow compilation
-#include <gnome.h>
-#else
 #include <glib.h>
 #include <libgnomeprint/gnome-print-encode.h>
-#endif
 
 #include "zlib.h"
 
@@ -64,7 +59,6 @@ int gnome_print_encode_deflate_wcs (gint size);
 /**
  * gnome_print_encode_blank :
  * @in: the row to analiyze
- * @out: not used.
  * @in_size: the size of the row
  * 
  * Scan the row and determine if it is a row with no data
@@ -189,14 +183,15 @@ gint gnome_print_encode_tiff_wcs (gint size)
 }
 
 /**
- * gnome_print_encode_tiff : Implements TIFF encodeion method for
- *                              PCL printers. Reference : [1]Page15-17.
- *             ( it should be useful for other Printer Languages too)
+ * gnome_print_encode_tiff : Implements TIFF encodeion method for PCL printers.
  * @in: the array containing the buffer of bytes that will be converted
  * @out: the output array in TIFF "Packbits"
  * @in_size: the size of the input buffer
+ *
+ * Reference: [1] Page15-17.
+ *             (it should be useful for other Printer Languages too).
  * 
- * returns : the size of the TIFF encodeed string
+ * Returns : the size of the TIFF encodeed string
  **/
 int
 gnome_print_encode_tiff (const guchar *in, guchar *out, gint in_size)
