@@ -40,8 +40,16 @@
 #include "config.h"
 #include <libgnomeprint/gnome-print-i18n.h>
 
-#include <gnome.h>
 #include <gdk/gdkkeysyms.h>
+#include <gtk/gtkaccelgroup.h>
+#include <gtk/gtkmenushell.h>
+#include <libgnomeui/gnome-app.h>
+#include <libgnomeui/gnome-app-helper.h>
+#include <libgnomeui/gnome-dialog.h>
+#include <libgnomeui/gnome-canvas.h>
+#include <libgnomeui/gnome-canvas-rect-ellipse.h>
+#include <libgnomeui/gnome-stock.h>
+
 #include <libgnomeprint/gnome-printer.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-meta.h>
