@@ -484,7 +484,7 @@ gnome_print_ps2_beginpage (GnomePrintContext *pc, const char *name)
 
 	ps2 = GNOME_PRINT_PS2 (pc);
 
-	g_return_val_if_fail (!ps2->pages || !ps2->pages->shown, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (!ps2->pages || ps2->pages->shown, GNOME_PRINT_ERROR_UNKNOWN);
 
 	number = ps2->pages ? ps2->pages->number : 0;
 
